@@ -21,11 +21,11 @@ Options:
 from __future__ import unicode_literals, print_function
 import sys
 import xerox
-from text.blob import TextBlob as tb
+from textblob import TextBlob as tb
 from docopt import docopt
 from clint.textui import puts, colored
 
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 __author__ = 'Steven Loria'
 __license__ = "MIT"
 
